==> developer-center-api-3.3.31-sources.jar: cn/com/duiba/developer/center/api/domain/dto/appextra/CustomServicePageConfigDto.java <==
package cn.com.duiba.developer.center.api.domain.dto.appextra;

import java.io.Serializable;

/**
 * 客服页面参数配置
 * Created by sty on 10/25/17.
 */
public class CustomServicePageConfigDto implements Serializable {
    private static final long serialVersionUID = -4567690471945274188L;
    //客服配置-安卓端显示图片
    private Boolean androidSendPic;
    //客服配置-用户来源是否展示
    private Boolean showSource;
    //客服配置-用户来源
    private String customerSource;
    //客服配置-是否vip
    private Boolean vip;
    //客服配置-是否关闭兑换记录客服
    private Boolean closeTradeRecordKeFu;
    //客服中间页
    private Boolean customerMiddlePage;
    //客服配置-开发者后台是否显示客诉来源
    private Boolean showDevSource;
    //客服配置-开发者后台客诉来源
    private String devSource;


    public Boolean getShowDevSource() {
        return showDevSource;
    }

    public void setShowDevSource(Boolean showDevSource) {
        this.showDevSource = showDevSource;
    }

    public String getDevSource() {
        return devSource;
    }

    public void setDevSource(String devSource) {
        this.devSource = devSource;
    }

    public Boolean getAndroidSendPic() {
        return androidSendPic;
    }

    public void setAndroidSendPic(Boolean androidSendPic) {
        this.androidSendPic = androidSendPic;
    }

    public Boolean getShowSource() {
        return showSource;
    }

    public void setShowSource(Boolean showSource) {
        this.showSource = showSource;
    }

    public String getCustomerSource() {
        return customerSource;
    }

    public void setCustomerSource(String customerSource) {
        this.customerSource = customerSource;
    }

    public Boolean getVip() {
        return vip;
    }

    public void setVip(Boolean vip) {
        this.vip = vip;
    }

    public Boolean getCloseTradeRecordKeFu() {
        return closeTradeRecordKeFu;
    }

    public void setCloseTradeRecordKeFu(Boolean closeTradeRecordKeFu) {
        this.closeTradeRecordKeFu = closeTradeRecordKeFu;
    }

    public Boolean getCustomerMiddlePage() {
        return customerMiddlePage;
    }

    public void setCustomerMiddlePage(Boolean customerMiddlePage) {
        this.customerMiddlePage = customerMiddlePage;
    }
}

==> developer-center-api-3.6.35-20211014.063808-3-sources.jar: cn/com/duiba/developer/center/api/domain/dto/appextra/CustomServicePageConfigDto.java <==
package cn.com.duiba.developer.center.api.domain.dto.appextra;

import java.io.Serializable;

/**
 * 客服页面参数配置
 * Created by sty on 10/25/17.
 */
public class CustomServicePageConfigDto implements Serializable {
    private static final long serialVersionUID = -4567690471945274188L;
    //客服配置-安卓端显示图片
    private Boolean androidSendPic;
    //客服配置-用户来源是否展示
    private Boolean showSource;
    //客服配置-用户来源
    private String customerSource;
    //客服配置-是否vip
    private Boolean vip;
    //客服配置-是否关闭兑换记录客服
    private Boolean closeTradeRecordKeFu;
    //客服中间页
    private Boolean customerMiddlePage;
    //客服配置-开发者后台是否显示客诉来源
    private Boolean showDevSource;
    //客服配置-开发者后台客诉来源
    private String devSource;
    // 客服配置-客服组配置
    // 0-兑吧普通 1-兑吧vip 2-复星客服
    private Integer qiyuVip;
    //客服配置-是否直接跳转人工客服
    private Boolean customerServiceByPeople;

    public Integer getQiyuVip() {
        return qiyuVip;
    }

    public void setQiyuVip(Integer qiyuVip) {
        this.qiyuVip = qiyuVip;
    }

    public Boolean getShowDevSource() {
        return showDevSource;
    }

    public void setShowDevSource(Boolean showDevSource) {
        this.showDevSource = showDevSource;
    }

    public String getDevSource() {
        return devSource;
    }

    public void setDevSource(String devSource) {
        this.devSource = devSource;
    }

    public Boolean getAndroidSendPic() {
        return androidSendPic;
    }

    public void setAndroidSendPic(Boolean androidSendPic) {
        this.androidSendPic = androidSendPic;
    }

    public Boolean getShowSource() {
        return showSource;
    }

    public void setShowSource(Boolean showSource) {
        this.showSource = showSource;
    }

    public String getCustomerSource() {
        return customerSource;
    }

    public void setCustomerSource(String customerSource) {
        this.customerSource = customerSource;
    }

    public Boolean getVip() {
        return vip;
    }

    public void setVip(Boolean vip) {
        this.vip = vip;
    }

    public Boolean getCloseTradeRecordKeFu() {
        return closeTradeRecordKeFu;
    }

    public void setCloseTradeRecordKeFu(Boolean closeTradeRecordKeFu) {
        this.closeTradeRecordKeFu = closeTradeRecordKeFu;
    }

    public Boolean getCustomerMiddlePage() {
        return customerMiddlePage;
    }

    public void setCustomerMiddlePage(Boolean customerMiddlePage) {
        this.customerMiddlePage = customerMiddlePage;
    }

    public Boolean getCustomerServiceByPeople() {
        return customerServiceByPeople;
    }

    public void setCustomerServiceByPeople(Boolean customerServiceByPeople) {
        this.customerServiceByPeople = customerServiceByPeople;
    }
}
